package javax.swing.plaf.metal;

import java.awt.FontMetrics;
import sun.swing.SwingUtilities2;
import java.awt.Rectangle;
import javax.swing.ButtonModel;
import javax.swing.plaf.UIResource;
import java.awt.Graphics;
import javax.swing.UIManager;
import javax.swing.AbstractButton;
import sun.awt.AppContext;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Color;
import javax.swing.plaf.basic.BasicToggleButtonUI;

public class MetalToggleButtonUI extends BasicToggleButtonUI
{
    private static final Object METAL_TOGGLE_BUTTON_UI_KEY;
    protected Color focusColor;
    protected Color selectColor;
    protected Color disabledTextColor;
    private boolean defaults_initialized;
    
    public MetalToggleButtonUI() {
        this.defaults_initialized = false;
    }
    
    public static ComponentUI createUI(JComponent component) {
        AppContext appContext = AppContext.getAppContext();
        MetalToggleButtonUI value = (MetalToggleButtonUI)appContext.get(MetalToggleButtonUI.METAL_TOGGLE_BUTTON_UI_KEY);
        if (value == null) {
            value = new MetalToggleButtonUI();
            appContext.put(MetalToggleButtonUI.METAL_TOGGLE_BUTTON_UI_KEY, value);
            return value;
        }
        return value;
    }
    
    public void installDefaults(AbstractButton b) {
        super.installDefaults(b);
        if (!this.defaults_initialized) {
            this.focusColor = UIManager.getColor(this.getPropertyPrefix() + "focus");
            this.selectColor = UIManager.getColor(this.getPropertyPrefix() + "select");
            this.disabledTextColor = UIManager.getColor(this.getPropertyPrefix() + "disabledText");
            this.defaults_initialized = true;
        }
    }
    
    @Override
    protected void uninstallDefaults(AbstractButton b) {
        super.uninstallDefaults(b);
        this.defaults_initialized = false;
    }
    
    protected Color getSelectColor() {
        return this.selectColor;
    }
    
    protected Color getDisabledTextColor() {
        return this.disabledTextColor;
    }
    
    protected Color getFocusColor() {
        return this.focusColor;
    }
    
    @Override
    public void update(Graphics g, JComponent c) {
        AbstractButton abstractButton = (AbstractButton)c;
        if (c.getBackground() instanceof UIResource && abstractButton.isContentAreaFilled() && c.isEnabled()) {
            ButtonModel model = abstractButton.getModel();
            if (!MetalUtils.isToolBarButton(c)) {
                if (!model.isArmed() && !model.isPressed() && MetalUtils.drawGradient(c, g, "ToggleButton.gradient", 0, 0, c.getWidth(), c.getHeight(), true)) {
                    this.paint(g, c);
                    return;
                }
            }
            else if ((model.isRollover() || model.isSelected()) && MetalUtils.drawGradient(c, g, "ToggleButton.gradient", 0, 0, c.getWidth(), c.getHeight(), true)) {
                this.paint(g, c);
                return;
            }
        }
        super.update(g, c);
    }
    
    @Override
    protected void paintButtonPressed(Graphics graphics, AbstractButton abstractButton) {
        if (abstractButton.isContentAreaFilled()) {
            graphics.setColor(this.getSelectColor());
            graphics.fillRect(0, 0, abstractButton.getWidth(), abstractButton.getHeight());
        }
    }
    
    @Override
    protected void paintText(Graphics graphics, JComponent c, Rectangle rectangle, String text) {
        AbstractButton c2 = (AbstractButton)c;
        ButtonModel model = c2.getModel();
        FontMetrics fontMetrics = SwingUtilities2.getFontMetrics(c2, graphics);
        int displayedMnemonicIndex = c2.getDisplayedMnemonicIndex();
        if (model.isEnabled()) {
            graphics.setColor(c2.getForeground());
        }
        else if (model.isSelected()) {
            graphics.setColor(c.getBackground());
        }
        else {
            graphics.setColor(this.getDisabledTextColor());
        }
        SwingUtilities2.drawStringUnderlineCharAt(c, graphics, text, displayedMnemonicIndex, rectangle.x, rectangle.y + fontMetrics.getAscent());
    }
    
    @Override
    protected void paintFocus(Graphics graphics, AbstractButton abstractButton, Rectangle rectangle, Rectangle rectangle2, Rectangle bounds) {
        Rectangle rectangle3 = new Rectangle();
        String text = abstractButton.getText();
        int n = abstractButton.getIcon() != null;
        if (text != null && !text.equals("")) {
            if (n == 0) {
                rectangle3.setBounds(rectangle2);
            }
            else {
                rectangle3.setBounds(bounds.union(rectangle2));
            }
        }
        else if (!(n == 0)) {
            rectangle3.setBounds(bounds);
        }
        graphics.setColor(this.getFocusColor());
        graphics.drawRect(rectangle3.x - 1, rectangle3.y - 1, rectangle3.width + 1, rectangle3.height + 1);
    }
    
    @Override
    protected void paintIcon(Graphics g, AbstractButton b, Rectangle iconRect) {
        super.paintIcon(g, b, iconRect);
    }
    
    static {
        METAL_TOGGLE_BUTTON_UI_KEY = new Object();
    }
}
